@@ -4,6 +4,7 @@ from __future__ import absolute_import
 
 
 from django.core import mail
+from django.contrib.auth.models import User
 from sentry.models import Project, ProjectKey, Group, Event, Team, \
   MessageFilterValue, MessageCountByMinute, FilterValue, PendingTeamMember
 
@@ -52,6 +53,17 @@ class ProjectKeyTest(TestCase):
         with self.Settings(SENTRY_URL_PREFIX='http://example.com:81'):
             self.assertEquals(key.get_dsn(), 'http://public:secret@example.com:81/default')
 
+    def test_key_is_created_for_project_with_existing_team(self):
+        user = User.objects.create(username='admin')
+        team = Team.objects.create(name='Test', slug='test', owner=user)
+        project = Project.objects.create(name='Test', slug='test', owner=user, team=team)
+        self.assertTrue(project.key_set.filter(user=user).exists())
+
+    def test_key_is_created_for_project_with_new_team(self):
+        user = User.objects.create(username='admin')
+        project = Project.objects.create(name='Test', slug='test', owner=user)
+        self.assertTrue(project.key_set.filter(user=user).exists())
+
 
 class PendingTeamMemberTest(TestCase):
     fixtures = ['tests/fixtures/views.json']
